<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Box2_Widget extends \Elementor\Widget_Base {

    public function get_name() {
        return 'box2';
    }

    public function get_title() {
        return __( 'باکس 2', 'naqshara' );
    }

    public function get_icon() {
        return 'eicon-alert';
    }

    public function get_categories() {
        return [ 'naqshara_category' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'content_section',
            [
                'label' => __( 'محتوا', 'naqshara' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        // Control for title
        $this->add_control(
            'box_title',
            [
                'label' => __( 'عنوان باکس', 'naqshara' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'به نقش آرا خوش آمدید', 'naqshara' ),
            ]
        );

        // Control for description
        $this->add_control(
            'box_description',
            [
                'label' => __( 'توضیحات', 'naqshara' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => __( 'وبسایت خود را با نقش آرا زیبا کنید!', 'naqshara' ),
            ]
        );

        // Control for box link
        $this->add_control(
            'box_link',
            [
                'label' => __( 'لینک باکس', 'naqshara' ),
                'type' => \Elementor\Controls_Manager::URL,
                'default' => [
                    'url' => '#',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $box_title = $settings['box_title'];
        $box_description = $settings['box_description'];
        $box_link = $settings['box_link']['url'];
        ?>
        <a href="<?php echo esc_url( $box_link ); ?>" class="notification">
            <div class="notiglow"></div>
            <div class="notiborderglow"></div>
            <div class="notititle"><?php echo esc_html( $box_title ); ?></div>
            <div class="notibody"><?php echo esc_html( $box_description ); ?></div>
        </a>
        <?php
    }

    protected function _content_template() {
        ?>
        <#
        var box_title = settings.box_title;
        var box_description = settings.box_description;
        var box_link = settings.box_link.url;
        #>
        <a href="{{ box_link }}" class="notification">
            <div class="notiglow"></div>
            <div class="notiborderglow"></div>
            <div class="notititle">{{{ box_title }}}</div>
            <div class="notibody">{{{ box_description }}}</div>
        </a>
        <?php
    }
}
