<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Box3_Widget extends \Elementor\Widget_Base {

    public function get_name() {
        return 'box3_widget';
    }

    public function get_title() {
        return __( 'باکس 3', 'plugin-name' );
    }

    public function get_icon() {
        return 'eicon-alert';
    }

    public function get_categories() {
        return [ 'naqshara_category' ];
    }
    protected function _register_controls() {

        $this->start_controls_section(
            'content_section',
            [
                'label' => __( 'محتوا', 'plugin-name' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => __( 'عنوان', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'لیست شما کامل شد!', 'plugin-name' ),
                'placeholder' => __( 'عنوان خود را وارد کنید!', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'description',
            [
                'label' => __( 'توضیحات', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => __( 'نقش نگار افزونه ای برای زیبا سازی وبسایت شما', 'plugin-name' ),
                'placeholder' => __( 'توضیحات خود را وارد کنید!', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'main_button_text',
            [
                'label' => __( 'دکمه اول', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'مشاهده سبد', 'plugin-name' ),
                'placeholder' => __( 'عنوان دکمه اول را وارد کنید', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'main_button_url',
            [
                'label' => __( 'لینک دکمه اول', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __( 'https://sizitop.com', 'plugin-name' ),
                'default' => [
                    'url' => '#',
                ],
            ]
        );

        $this->add_control(
            'secondary_button_text',
            [
                'label' => __( 'عنوان دکمه دوم', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'خروج', 'plugin-name' ),
                'placeholder' => __( 'عنوان دکمه دوم خود را وارد کنید', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'secondary_button_url',
            [
                'label' => __( 'لینک دکمه دوم', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __( 'https://sizitop.com', 'plugin-name' ),
                'default' => [
                    'url' => '#',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="notifications-container">
            <div class="success">
                <div class="flex">
                    <div class="flex-shrink-0">
                        <svg class="succes-svg" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20" fill="currentColor" aria-hidden="true">
                            <path fill-rule="evenodd" d="M10 18a8 8 0 100-16 8 8 0 000 16zm3.707-9.293a1 1 0 00-1.414-1.414L9 10.586 7.707 9.293a1 1 0 00-1.414 1.414l2 2a1 1 0 001.414 0l4-4z" clip-rule="evenodd"></path>
                        </svg>
                    </div>
                    <div class="success-prompt-wrap">
                        <p class="success-prompt-heading"><?php echo $settings['title']; ?></p>
                        <div class="success-prompt-prompt">
                            <p><?php echo $settings['description']; ?></p>
                        </div>
                        <div class="success-button-container">
                            <a href="<?php echo $settings['main_button_url']['url']; ?>" class="success-button-main"><?php echo $settings['main_button_text']; ?></a>
                            <a href="<?php echo $settings['secondary_button_url']['url']; ?>" class="success-button-secondary"><?php echo $settings['secondary_button_text']; ?></a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }

    protected function _content_template() {
        ?>
        <#
        var mainButtonUrl = settings.main_button_url.url ? settings.main_button_url.url : '#';
        var secondaryButtonUrl = settings.secondary_button_url.url ? settings.secondary_button_url.url : '#';
        #>
        <div class="notifications-container">
            <div class="success">
                <div class="flex">
                    <div class="flex-shrink-0">
                        <svg class="succes-svg" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20" fill="currentColor" aria-hidden="true">
                            <path fill-rule="evenodd" d="M10 18a8 8 0 100-16 8 8 0 000 16zm3.707-9.293a1 1 0 00-1.414-1.414L9 10.586 7.707 9.293a1 1 0 00-1.414 1.414l2 2a1 1 0 001.414 0l4-4z" clip-rule="evenodd"></path>
                        </svg>
                    </div>
                    <div class="success-prompt-wrap">
                        <p class="success-prompt-heading">{{{ settings.title }}}</p>
                        <div class="success-prompt-prompt">
                            <p>{{{ settings.description }}}</p>
                        </div>
                        <div class="success-button-container">
                            <a href="{{ mainButtonUrl }}" class="success-button-main">{{{ settings.main_button_text }}}</a>
                            <a href="{{ secondaryButtonUrl }}" class="success-button-secondary">{{{ settings.secondary_button_text }}}</a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }
}
