<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Box4_Widget extends \Elementor\Widget_Base {

    public function get_name() {
        return 'box4_widget';
    }

    public function get_title() {
        return __( 'باکس 4', 'plugin-name' );
    }

    public function get_icon() {
        return 'eicon-notification';
    }

    public function get_categories() {
        return [ 'naqshara_category' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'content_section',
            [
                'label' => __( 'محتوا', 'plugin-name' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => __( 'عنوان باکس', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'خرید انجام شد!', 'plugin-name' ),
                'placeholder' => __( 'عنوان خود را وارد کنید', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'description',
            [
                'label' => __( 'توضیحات', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => __( 'ممنون از خرید شما! سفارش شما آماده هست.', 'plugin-name' ),
                'placeholder' => __( 'توضیحات خود را وارد کنید!', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'main_button_text',
            [
                'label' => __( 'عنوان دکمه اول', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'مشاهده سفارش', 'plugin-name' ),
                'placeholder' => __( 'عنوان دکمه اول خود را وارد کنید', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'main_button_url',
            [
                'label' => __( 'لینک دکمه اول', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __( 'https://sizitop.com', 'plugin-name' ),
                'default' => [
                    'url' => '#',
                ],
            ]
        );

        $this->add_control(
            'secondary_button_text',
            [
                'label' => __( 'عنوان دکمه دوم', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'خروج از حساب کاربری', 'plugin-name' ),
                'placeholder' => __( 'عنوان دکمه دوم خود را وارد کنید', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'secondary_button_url',
            [
                'label' => __( 'لینک دکمه دوم', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __( 'https://sizitop.com', 'plugin-name' ),
                'default' => [
                    'url' => '#',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="random-card">
            <div class="random-header">
                <div class="random-image">
                    <svg viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <path stroke-linejoin="round" stroke-linecap="round" stroke-width="1.5" stroke="#000000" d="M20 7L9.00004 18L3.99994 13"></path>
                    </svg>
                </div>
                <div class="random-content">
                    <span class="random-title"><?php echo esc_html($settings['title']); ?></span>
                    <p class="random-message"><?php echo esc_html($settings['description']); ?></p>
                </div>
                <div class="random-actions">
                    <a href="<?php echo esc_url($settings['main_button_url']['url']); ?>" class="random-history"><?php echo esc_html($settings['main_button_text']); ?></a>
                    <a href="<?php echo esc_url($settings['secondary_button_url']['url']); ?>" class="random-track"><?php echo esc_html($settings['secondary_button_text']); ?></a>
                </div>
            </div>
        </div>
        <?php
    }

    protected function _content_template() {
        ?>
        <#
        var mainButtonUrl = settings.main_button_url.url ? settings.main_button_url.url : '#';
        var secondaryButtonUrl = settings.secondary_button_url.url ? settings.secondary_button_url.url : '#';
        #>
        <div class="random-card">
            <div class="random-header">
                <div class="random-image">
                    <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
                        <path stroke-linejoin="round" stroke-linecap="round" stroke-width="1.5" stroke="#000000" d="M20 7L9.00004 18L3.99994 13"></path>
                    </svg>
                </div>
                <div class="random-content">
                    <span class="random-title">{{{ settings.title }}}</span>
                    <p class="random-message">{{{ settings.description }}}</p>
                </div>
                <div class="random-actions">
                    <a href="{{ mainButtonUrl }}" class="random-history">{{{ settings.main_button_text }}}</a>
                    <a href="{{ secondaryButtonUrl }}" class="random-track">{{{ settings.secondary_button_text }}}</a>
                </div>
            </div>
        </div>
        <?php
    }
}
