<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Box6_Widget extends \Elementor\Widget_Base {

    public function get_name() {
        return 'box6_widget';
    }

    public function get_title() {
        return __( 'باکس 6', 'plugin-name' );
    }

    public function get_icon() {
        return 'eicon-editor-code';
    }

    public function get_categories() {
        return [ 'naqshara_category' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'content_section',
            [
                'label' => __( 'محتوا', 'plugin-name' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => __( 'عنوان باکس', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'هاور کن!', 'plugin-name' ),
                'placeholder' => __( 'عنوان خود را وارد کنید', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'description',
            [
                'label' => __( 'توضیحات', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
                'default' => __( 'نقش آوا افزونه ای برای زیبا سازی وبسایت شما که توسط سیزی تاپ نوشته شده است!', 'plugin-name' ),
                'placeholder' => __( 'توضیحات خود را وارد کنید!', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'link',
            [
                'label' => __( 'لینک باکس', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __( 'https://sizitop.com', 'plugin-name' ),
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $target = $settings['link']['is_external'] ? ' target="_blank"' : '';
        $nofollow = $settings['link']['nofollow'] ? ' rel="nofollow"' : '';
        ?>
        <a href="<?php echo esc_url( $settings['link']['url'] ); ?>"<?php echo $target . $nofollow; ?>>
            <div class="sep">
                <div class="align">
                    <span class="red"></span>
                    <span class="yellow"></span>
                    <span class="green"></span>
                </div>

                <h1><?php echo $settings['title']; ?></h1>
                <p><?php echo $settings['description']; ?></p>
            </div>
        </a>
        <?php
    }

    protected function _content_template() {
        ?>
        <# var target = settings.link.is_external ? ' target="_blank"' : ''; var nofollow = settings.link.nofollow ? ' rel="nofollow"' : ''; #>
        <a href="{{ settings.link.url }}"{{ target }}{{ nofollow }}>
            <div class="sep">
                <div class="align">
                    <span class="red"></span>
                    <span class="yellow"></span>
                    <span class="green"></span>
                </div>

                <h1>{{{ settings.title }}}</h1>
                <p>{{{ settings.description }}}</p>
            </div>
        </a>
        <?php
    }
}
