<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Box7_Widget extends \Elementor\Widget_Base {

    public function get_name() {
        return 'box7_widget';
    }

    public function get_title() {
        return __( 'باکس 7', 'plugin-name' );
    }

    public function get_icon() {
        return 'eicon-editor-code';
    }

    public function get_categories() {
        return [ 'naqshara_category' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'content_section',
            [
                'label' => __( 'محتوا', 'plugin-name' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => __( 'عنوان باکس', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'پلن ویژه', 'plugin-name' ),
                'placeholder' => __( 'عنوان خود را وارد کنید!', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'price',
            [
                'label' => __( 'قیمت', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( '100 تومان/ماه', 'plugin-name' ),
                'placeholder' => __( 'قیمت خود را وارد کنید!', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'features',
            [
                'label' => __( 'آیتم ها', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => [
                    [
                        'name' => 'feature',
                        'label' => __( 'آیتم ها', 'plugin-name' ),
                        'type' => \Elementor\Controls_Manager::TEXT,
                        'default' => __( 'آیتم جدید!', 'plugin-name' ),
                    ],
                ],
                'default' => [
                    [
                        'feature' => __( 'بهترین پشتیبانی', 'plugin-name' ),
                    ],
                    [
                        'feature' => __( 'بهترین هزینه', 'plugin-name' ),
                    ],
                    [
                        'feature' => __( 'بدون تبلیغات', 'plugin-name' ),
                    ],
                ],
                'title_field' => '{{{ feature }}}',
            ]
        );

        $this->add_control(
            'button_text',
            [
                'label' => __( 'عنوان دکمه', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'خرید کن!', 'plugin-name' ),
                'placeholder' => __( 'عنوان دکمه خود را وارد کنید!', 'plugin-name' ),
            ]
        );

        $this->add_control(
            'link',
            [
                'label' => __( 'لینک دکمه', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __( 'https://sizitop.com', 'plugin-name' ),
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $target = $settings['link']['is_external'] ? ' target="_blank"' : '';
        $nofollow = $settings['link']['nofollow'] ? ' rel="nofollow"' : '';

        ?>
        <div class="xqpf__rfnv">
            <div class="xqpf__llnv kclw">
                <p class="kclw__jslw"><?php echo esc_html( $settings['title'] ); ?></p>
                <p class="kclw__vxnd"><?php echo esc_html( $settings['price'] ); ?></p>
                <ul class="kclw_fznp yjkn" role="list">
                    <?php foreach ( $settings['features'] as $feature ) : ?>
                        <li><?php echo esc_html( $feature['feature'] ); ?></li>
                    <?php endforeach; ?>
                </ul>
                <a class="kclw__crxy cta" href="<?php echo esc_url( $settings['link']['url'] ); ?>"<?php echo $target . $nofollow; ?>>
                    <?php echo esc_html( $settings['button_text'] ); ?>
                </a>
            </div>
            <div class="kfwz xqpf__rfnv"></div>
        </div>
        <?php
    }

    protected function _content_template() {
        ?>
        <#
        var target = settings.link.is_external ? ' target="_blank"' : '';
        var nofollow = settings.link.nofollow ? ' rel="nofollow"' : '';
        #>
        <div class="xqpf__rfnv">
            <div class="xqpf__llnv kclw">
                <p class="kclw__jslw">{{{ settings.title }}}</p>
                <p class="kclw__vxnd">{{{ settings.price }}}</p>
                <ul class="kclw_fznp yjkn" role="list">
                    <# _.each( settings.features, function( feature ) { #>
                        <li>{{{ feature.feature }}}</li>
                    <# }); #>
                </ul>
                <a class="kclw__crxy cta" href="{{ settings.link.url }}"{{ target }}{{ nofollow }}>
                    {{{ settings.button_text }}}
                </a>
            </div>
            <div class="kfwz xqpf__rfnv"></div>
        </div>
        <?php
    }
}
