<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Box9_Widget extends \Elementor\Widget_Base {

    public function get_name() {
        return 'box9_widget';
    }

    public function get_title() {
        return __( 'باکس 9', 'naqshara' );
    }

    public function get_icon() {
        return 'eicon-progress-bar';
    }

    public function get_categories() {
        return [ 'naqshara_category' ]; 
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'content_section',
            [
                'label' => __( 'محتوا', 'naqshara' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'header_title',
            [
                'label' => __( 'عنوان اصلی', 'naqshara' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'مهارت‌های من', 'naqshara' ),
            ]
        );

        for ($i = 1; $i <= 3; $i++) {
            $this->add_control(
                "skill_{$i}_title",
                [
                    'label' => __( "عنوان مهارت {$i}", 'naqshara' ),
                    'type' => \Elementor\Controls_Manager::TEXT,
                    'default' => __( "مهارت {$i}", 'naqshara' ),
                ]
            );

            $this->add_control(
                "skill_{$i}_percentage",
                [
                    'label' => __( "درصد مهارت {$i}", 'naqshara' ),
                    'type' => \Elementor\Controls_Manager::NUMBER,
                    'default' => 75,
                    'min' => 0,
                    'max' => 100,
                    'step' => 1,
                ]
            );
        }

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        ?>
        <div class="magic-card">
            <div class="header-title"><?php echo esc_html($settings['header_title']); ?></div>
            <div class="content-area">
                <?php for ($i = 1; $i <= 3; $i++) : 
                    $title = $settings["skill_{$i}_title"];
                    $percentage = $settings["skill_{$i}_percentage"];
                ?>
                    <div class="ability">
                        <div class="ability-name"><?php echo esc_html($title); ?></div>
                        <div class="ability-level">
                            <div class="ability-percent" style="width: <?php echo esc_attr($percentage); ?>%;"></div>
                        </div>
                        <div class="ability-percent-number"><?php echo esc_html($percentage); ?>%</div>
                    </div>
                <?php endfor; ?>
            </div>
        </div>
        <?php
    }

    protected function _content_template() {
        ?>
        <div class="magic-card">
            <div class="header-title">{{{ settings.header_title }}}</div>
            <div class="content-area">
                <# for ( var i = 1; i <= 3; i++ ) {
                    var title = settings['skill_' + i + '_title'];
                    var percentage = settings['skill_' + i + '_percentage'];
                #>
                    <div class="ability">
                        <div class="ability-name">{{{ title }}}</div>
                        <div class="ability-level">
                            <div class="ability-percent" style="width: {{{ percentage }}}%;"></div>
                        </div>
                        <div class="ability-percent-number">{{{ percentage }}}%</div>
                    </div>
                <# } #>
            </div>
        </div>
        <?php
    }
}
