<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Button9_Widget extends \Elementor\Widget_Base {

    public function get_name() {
        return 'button9';
    }

    public function get_title() {
        return __( 'دکمه 9', 'naqshara' );
    }

    public function get_icon() {
        return 'eicon-button';
    }

    public function get_categories() {
        return [ 'naqshara_category' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'content_section',
            [
                'label' => __( 'محتوا', 'naqshara' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'button_text',
            [
                'label' => __( 'عنوان دکمه', 'naqshara' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => __( 'تماشا کنید!', 'naqshara' ),
                'placeholder' => __( 'عنوان دکمه را وارد کنید', 'naqshara' ),
            ]
        );

        $this->add_control(
            'button_link',
            [
                'label' => __( 'لینک دکمه', 'naqshara' ),
                'type' => \Elementor\Controls_Manager::URL,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                ],
                'placeholder' => __( 'https://sizitop.com', 'naqshara' ),
                'show_external' => true,
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $button_text = $settings['button_text'];
        $button_link = $settings['button_link']['url'];
        $target = $settings['button_link']['is_external'] ? ' target="_blank"' : '';
        $nofollow = $settings['button_link']['nofollow'] ? ' rel="nofollow"' : '';

        ?>
        <a href="<?php echo esc_url( $button_link ); ?>"<?php echo $target; ?><?php echo $nofollow; ?>>
            <button class="nhy"><?php echo esc_html( $button_text ); ?></button>
        </a>
        <?php
    }

    protected function _content_template() {
        ?>
        <#
        var button_text = settings.button_text;
        var button_link = settings.button_link.url;
        var target = settings.button_link.is_external ? ' target="_blank"' : '';
        var nofollow = settings.button_link.nofollow ? ' rel="nofollow"' : '';
        #>
        <a href="{{ button_link }}"{{ target }}{{ nofollow }}>
            <button class="nhy">{{{ button_text }}}</button>
        </a>
        <?php
    }
}
